from flash.tabular.classification import TabularClassificationData, TabularClassifier  # noqa: F401
from flash.tabular.data import TabularData  # noqa: F401
from flash.tabular.forecasting.data import TabularForecastingData  # noqa: F401
from flash.tabular.regression import TabularRegressionData, TabularRegressor  # noqa: F401
